==> hyades.source_3.0.0_20040621_1225.zip: org/eclipse/hyades/trace/ui/internal/launcher/defaults/MemoryHeapUI.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.launcher.defaults;


import org.eclipse.hyades.security.util.GridUtil;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.*;
import org.eclipse.swt.layout.*;
import org.eclipse.swt.widgets.*;


public class MemoryHeapUI{
	
	private Composite _detailsHeapGroup;
	private Button _showHeapInstance;
	
	private Label titleLabel;
	private Label optionsLabel;

	private boolean _enableHeap = false;	
	

	public MemoryHeapUI() {
		super();
	}

	public Composite createControl(Composite parent) {
		
		GridLayout layout;

		Composite result = new Composite(parent, SWT.NONE);

		layout = new GridLayout();
		layout.numColumns = 1;
		layout.verticalSpacing = 2;

		GridData data = GridUtil.createFill();
		result.setLayout(layout);
		result.setLayoutData(data);
		
		titleLabel = new Label(result, SWT.NULL);
		titleLabel.setText(UIPlugin.getResourceString("memoryType"));
		titleLabel.setLayoutData(GridUtil.createHorizontalFill());
		//white
		titleLabel.setBackground(new Color(null, 255, 255, 255));
		titleLabel.setFont(new Font(null, "Arial", 13, SWT.BOLD));

		new Label(result, SWT.NULL);

		optionsLabel = new Label(result, SWT.WRAP);
		optionsLabel.setText(UIPlugin.getResourceString("STR_ANALYZE_HEAP"));
		data = new GridData();
		data.horizontalIndent = 20;
		data.widthHint = 375;
		optionsLabel.setLayoutData(data);


		Composite grp = new Composite(result, SWT.NULL);
		data = GridUtil.createHorizontalFill();
		layout = new GridLayout();
		layout.numColumns = 1;
		grp.setLayout(layout);
		grp.setLayoutData(data);
		
		addHeapOption(grp);
		_detailsHeapGroup.setVisible(true);

		return result;
	}

	private void addHeapOption(Composite parent) {
		GridLayout layout;
		GridData data;

		//title -  Memory/Heap Analysis
		//	Options label
	
		
		_detailsHeapGroup = new Composite(parent, SWT.NULL);
		data = GridUtil.createHorizontalFill();
		data.horizontalIndent = 20;
		_detailsHeapGroup.setLayoutData(data);
		layout = new GridLayout();
		layout.numColumns = 1;
		_detailsHeapGroup.setLayout(layout);

		_showHeapInstance = new Button(_detailsHeapGroup, SWT.CHECK);
		_showHeapInstance.setText(
			UIPlugin.getResourceString("STR_SHOW_INST_LEVEL_INFO"));

		org.eclipse.ui.help.WorkbenchHelp.setHelp(
			_showHeapInstance,
			UIPlugin.getPluginId() + ".topp0011");
	}

	public void enableButtons() {

		enableBtnGroup();
	}

	public void enableBtnGroup() {
		enableHeptBtnGroup();
	}

	private void enableHeptBtnGroup() {
		_showHeapInstance.setEnabled(true);
	}
	
	public void enableHeapInfo(boolean enable) {
		_enableHeap = enable;

		if (!enable) {
			_showHeapInstance.setEnabled(false);
		}
	}
	
	public boolean getHeapDetails() {
		return _showHeapInstance.getSelection();
	}

	public void setHeapDetails(boolean setValue) {
		_showHeapInstance.setSelection(setValue);
	}
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/trace/ui/internal/launcher/defaults/MemoryHeapUI.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: MemoryHeapUI.java,v 1.7 2005/03/11 04:07:08 popescu Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.launcher.defaults;


import org.eclipse.hyades.security.util.GridUtil;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.*;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.*;
import org.eclipse.swt.layout.*;
import org.eclipse.swt.widgets.*;


public class MemoryHeapUI  implements SelectionListener
{
	
	private Composite _detailsHeapGroup;
	private Button _showHeapInstance;
	
	private Label titleLabel;
	private Label optionsLabel;
	private Button _advancedOptions;
	private Composite _heapOptionGrp;

	private boolean _enableHeap = false;	
	

	public MemoryHeapUI() {
		super();
	}

	public Composite createControl(Composite parent) {
		
		GridLayout layout;

		Composite result = new Composite(parent, SWT.NONE);

		layout = new GridLayout();
		layout.numColumns = 1;
		layout.verticalSpacing = 2;

		GridData data = GridUtil.createFill();
		result.setLayout(layout);
		result.setLayoutData(data);
		
		titleLabel = new Label(result, SWT.NULL);
		titleLabel.setText(UIPlugin.getResourceString("memoryType"));
		titleLabel.setLayoutData(GridUtil.createHorizontalFill());
		//white
		titleLabel.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));
		Font font = titleLabel.getFont();
		if (font != null) {
			FontData[] fonts = font.getFontData();
			if (fonts != null && fonts.length >= 1) {
				titleLabel.setFont(new Font(Display.getDefault(), fonts[0].getName(), fonts[0].getHeight() + 3, SWT.BOLD));
			}
		}

		new Label(result, SWT.NULL);

		optionsLabel = new Label(result, SWT.WRAP);
		optionsLabel.setText(UIPlugin.getResourceString("STR_ANALYZE_HEAP"));
		data = new GridData();
		data.horizontalIndent = 20;
		data.widthHint = 375;
		optionsLabel.setLayoutData(data);


		Composite grp = new Composite(result, SWT.NULL);
		data = GridUtil.createHorizontalFill();
		layout = new GridLayout();
		layout.numColumns = 1;
		grp.setLayout(layout);
		grp.setLayoutData(data);
		
		addHeapOption(grp);
		_detailsHeapGroup.setVisible(true);

		return result;
	}

	private void addHeapOption(Composite parent) {
		GridLayout layout;
		GridData data;

		_detailsHeapGroup = new Composite(parent, SWT.NULL);
		data = GridUtil.createHorizontalFill();
		data.horizontalIndent = 20;
		_detailsHeapGroup.setLayoutData(data);
		layout = new GridLayout();
		layout.numColumns = 1;
		_detailsHeapGroup.setLayout(layout);

		_advancedOptions = new Button(_detailsHeapGroup, SWT.PUSH);
		_advancedOptions.setText(UIPlugin.getResourceString("STR_ADVANCED_BTN"));
		_advancedOptions.addSelectionListener(this);

		_heapOptionGrp = new Composite(_detailsHeapGroup, SWT.NULL);
		_heapOptionGrp.setLayout(new GridLayout());
		
		_showHeapInstance = new Button(_heapOptionGrp, SWT.CHECK);
		_showHeapInstance.setText(
				UIPlugin.getResourceString("STR_SHOW_INST_LEVEL_INFO"));						
		
		Label info = new Label(_heapOptionGrp, SWT.NULL);
		data = GridUtil.createHorizontalFill();
		info.setLayoutData(data);
		info.setForeground(Display.getCurrent().getSystemColor(SWT.COLOR_RED));
		info.setImage(Display.getCurrent().getSystemImage(SWT.ICON_WARNING));
		info.setText(UIPlugin.getResourceString("STR_INSTANCE_LEVEL_INFO"));
		
		_heapOptionGrp.setVisible(false);

		org.eclipse.ui.help.WorkbenchHelp.setHelp(
			_showHeapInstance,
			UIPlugin.getPluginId() + ".topp0011");
	}

	public void enableButtons() {

		enableBtnGroup();
	}

	public void enableBtnGroup() {
		enableHeptBtnGroup();
	}

	private void enableHeptBtnGroup() {
		_showHeapInstance.setEnabled(true);
	}
	
	public void enableHeapInfo(boolean enable) {
		_enableHeap = enable;

		if (!enable) {
			_showHeapInstance.setEnabled(false);
		}
	}
	
	public boolean getHeapDetails() {
		return _showHeapInstance.getSelection();
	}

	public void setHeapDetails(boolean setValue) {
		_showHeapInstance.setSelection(setValue);
	}
	
	public void widgetDefaultSelected(SelectionEvent event) {
	}

	public void widgetSelected(SelectionEvent event) {
		if (event.widget == _advancedOptions) {
			_heapOptionGrp.setVisible(!_heapOptionGrp.getVisible());
		}
	}
	
}
